# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-23 12:07
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('site_config', '0002_auto_20170714_1028'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='configfield',
            options={'ordering': ['label'], 'verbose_name': 'settings', 'verbose_name_plural': 'settings'},
        ),
        migrations.AddField(
            model_name='configfield',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='group',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='site_config.ConfigGroup', verbose_name='Group'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='type',
            field=models.CharField(choices=[(b'input', 'Input'), (b'text', 'Text'), (b'html', 'HTML'), (b'int', 'Integer'), (b'float', 'Float'), (b'bool', 'True / False'), (b'url', 'Url'), (b'email', 'Email'), (b'file', 'File'), (b'image', 'Image'), (b'json', 'JSON')], max_length=50, verbose_name='Type'),
        ),
        migrations.AlterField(
            model_name='configfield',
            name='value_input',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Input'),
        ),
        migrations.AlterUniqueTogether(
            name='configfield',
            unique_together=set([('site', 'name')]),
        ),
    ]
