# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-04-13 05:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ConfigField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.CharField(max_length=255, verbose_name='Label')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('type', models.CharField(choices=[(b'input', 'Input'), (b'text', 'Text'), (b'int', 'Integer'), (b'float', 'Float'), (b'bool', 'True / False'), (b'url', 'Url'), (b'email', 'Email'), (b'file', 'File'), (b'image', 'Image')], max_length=50, verbose_name='Type')),
                ('splitter', models.CharField(blank=True, choices=[(b'newline', 'New line'), (b',', 'Comma'), (b'.', 'Dot'), (b';', 'Semicolon'), (b' ', 'Tab')], max_length=10, null=True, verbose_name='Splitter')),
                ('value_input', models.CharField(blank=True, max_length=255, null=True, verbose_name='Text')),
                ('value_text', models.TextField(blank=True, max_length=10000, null=True, verbose_name='Text')),
                ('value_int', models.IntegerField(blank=True, null=True, verbose_name='Integer')),
                ('value_float', models.IntegerField(blank=True, null=True, verbose_name='Float')),
                ('value_bool', models.NullBooleanField(verbose_name='Boolean')),
                ('value_url', models.URLField(blank=True, null=True, verbose_name='Url')),
                ('value_email', models.EmailField(blank=True, max_length=254, null=True, verbose_name='Email')),
                ('value_file', models.FileField(blank=True, null=True, upload_to=b'site_config', verbose_name='File')),
                ('value_image', models.ImageField(blank=True, null=True, upload_to=b'site_config', verbose_name='Image')),
            ],
            options={
                'ordering': ['type'],
                'verbose_name': 'settings',
                'verbose_name_plural': 'settings',
            },
        ),
    ]
